@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,9 +20,7 @@ SieveHelpButton::SieveHelpButton(QWidget *parent)
     setIcon(QIcon::fromTheme(QStringLiteral("help-hint")));
 }
 
-SieveHelpButton::~SieveHelpButton()
-{
-}
+SieveHelpButton::~SieveHelpButton() = default;
 
 bool SieveHelpButton::event(QEvent *event)
 {
