@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,12 +14,10 @@ SelectVariableModifierComboBox::SelectVariableModifierComboBox(QWidget *parent)
     : QComboBox(parent)
 {
     initialize();
-    connect(this, QOverload<int>::of(&SelectVariableModifierComboBox::activated), this, &SelectVariableModifierComboBox::valueChanged);
+    connect(this, &SelectVariableModifierComboBox::activated, this, &SelectVariableModifierComboBox::valueChanged);
 }
 
-SelectVariableModifierComboBox::~SelectVariableModifierComboBox()
-{
-}
+SelectVariableModifierComboBox::~SelectVariableModifierComboBox() = default;
 
 void SelectVariableModifierComboBox::initialize()
 {
