@@ -1,26 +1,27 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveglobalvariablewidget.h"
-#include "sievescriptblockwidget.h"
 #include "autocreatescriptutil_p.h"
 #include "commonwidgets/sievehelpbutton.h"
 #include "editor/sieveeditorutil.h"
+#include "sievescriptblockwidget.h"
 #include "widgets/lineeditvalidator.h"
 
-#include <QPushButton>
 #include <KLocalizedString>
-#include <QLineEdit>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QIcon>
+#include <QLineEdit>
+#include <QPushButton>
 
-#include <QGridLayout>
+#include "libksieve_debug.h"
 #include <QCheckBox>
+#include <QGridLayout>
 #include <QLabel>
 #include <QWhatsThis>
-#include "libksieve_debug.h"
 #include <QXmlStreamReader>
 
 using namespace KSieveUi;
@@ -33,9 +34,7 @@ SieveGlobalVariableActionWidget::SieveGlobalVariableActionWidget(QWidget *parent
     initWidget();
 }
 
-SieveGlobalVariableActionWidget::~SieveGlobalVariableActionWidget()
-{
-}
+SieveGlobalVariableActionWidget::~SieveGlobalVariableActionWidget() = default;
 
 void SieveGlobalVariableActionWidget::generatedScript(QString &script)
 {
@@ -55,19 +54,20 @@ void SieveGlobalVariableActionWidget::initWidget()
     mLayout = new QGridLayout(this);
     mLayout->setContentsMargins({});
 
-    QLabel *lab = new QLabel(i18n("Variable name:"));
+    auto lab = new QLabel(i18n("Variable name:"), this);
     mLayout->addWidget(lab, 1, 0);
 
-    mVariableName = new LineEditValidator;
+    mVariableName = new LineEditValidator(this);
     connect(mVariableName, &QLineEdit::textChanged, this, &SieveGlobalVariableActionWidget::valueChanged);
     mLayout->addWidget(mVariableName, 1, 1);
 
-    mSetValueTo = new QCheckBox(i18n("Set value to:"));
+    mSetValueTo = new QCheckBox(i18n("Set value to:"), this);
     connect(mSetValueTo, &QCheckBox::toggled, this, &SieveGlobalVariableActionWidget::valueChanged);
     mLayout->addWidget(mSetValueTo, 1, 2);
     mSetValueTo->setChecked(false);
 
-    mVariableValue = new QLineEdit;
+    mVariableValue = new QLineEdit(this);
+    new KPIM::LineEditCatchReturnKey(mVariableValue, this);
     connect(mVariableValue, &QLineEdit::textChanged, this, &SieveGlobalVariableActionWidget::valueChanged);
     mVariableValue->setEnabled(false);
     mLayout->addWidget(mVariableValue, 1, 3);
@@ -120,11 +120,20 @@ void SieveGlobalVariableActionWidget::setVariableValue(const QString &name)
 void SieveGlobalVariableActionWidget::loadScript(QXmlStreamReader &element, QString &error)
 {
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("str")) {
             mVariableName->setText(element.readElementText());
         } else {
-            error += i18n("Unknown tag \"%1\" during loading of variables.", *tagName.string()) + QLatin1Char('\n');
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+            const QString result = *tagName.string();
+#else
+            const QString result = tagName.toString();
+#endif
+            error += i18n("Unknown tag \"%1\" during loading of variables.", result) + QLatin1Char('\n');
             qCDebug(LIBKSIEVE_LOG) << " SieveGlobalVariableActionWidget::loadScript unknown tagName " << tagName;
         }
     }
@@ -151,7 +160,7 @@ void SieveGlobalVariableActionWidget::updateAddRemoveButton(bool addButtonEnable
 SieveGlobalVariableWidget::SieveGlobalVariableWidget(QWidget *parent)
     : SieveWidgetPageAbstract(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     mHelpButton = new SieveHelpButton(this);
     lay->addWidget(mHelpButton);
     connect(mHelpButton, &SieveHelpButton::clicked, this, &SieveGlobalVariableWidget::slotHelp);
@@ -162,14 +171,13 @@ SieveGlobalVariableWidget::SieveGlobalVariableWidget(QWidget *parent)
     setPageType(KSieveUi::SieveScriptBlockWidget::GlobalVariable);
 }
 
-SieveGlobalVariableWidget::~SieveGlobalVariableWidget()
-{
-}
+SieveGlobalVariableWidget::~SieveGlobalVariableWidget() = default;
 
 void SieveGlobalVariableWidget::slotHelp()
 {
     const QString help = i18n(
-        "A variable has global scope in all scripts that have declared it with the \"global\" command.  If a script uses that variable name without declaring it global, the name specifies a separate, non-global variable within that script.");
+        "A variable has global scope in all scripts that have declared it with the \"global\" command.  If a script uses that variable name without declaring "
+        "it global, the name specifies a separate, non-global variable within that script.");
     const QUrl href = KSieveUi::SieveEditorUtil::helpUrl(KSieveUi::SieveEditorUtil::GlobalVariable);
     const QString fullWhatsThis = AutoCreateScriptUtil::createFullWhatsThis(help, href.toString());
     QWhatsThis::showText(QCursor::pos(), fullWhatsThis, mHelpButton);
@@ -204,9 +212,7 @@ SieveGlobalVariableLister::SieveGlobalVariableLister(QWidget *parent)
     updateAddRemoveButton();
 }
 
-SieveGlobalVariableLister::~SieveGlobalVariableLister()
-{
-}
+SieveGlobalVariableLister::~SieveGlobalVariableLister() = default;
 
 void SieveGlobalVariableLister::slotAddWidget(QWidget *w)
 {
@@ -239,7 +245,7 @@ void SieveGlobalVariableLister::updateAddRemoveButton()
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        auto *w = qobject_cast<SieveGlobalVariableActionWidget *>(*wIt);
+        auto w = qobject_cast<SieveGlobalVariableActionWidget *>(*wIt);
         w->updateAddRemoveButton(addButtonEnabled, removeButtonEnabled);
     }
 }
@@ -251,7 +257,7 @@ void SieveGlobalVariableLister::generatedScript(QString &script, QStringList &re
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        auto *w = qobject_cast<SieveGlobalVariableActionWidget *>(*wIt);
+        auto w = qobject_cast<SieveGlobalVariableActionWidget *>(*wIt);
         w->generatedScript(script);
     }
 }
@@ -266,7 +272,7 @@ void SieveGlobalVariableLister::reconnectWidget(SieveGlobalVariableActionWidget
 void SieveGlobalVariableLister::clearWidget(QWidget *aWidget)
 {
     if (aWidget) {
-        auto *widget = static_cast<SieveGlobalVariableActionWidget *>(aWidget);
+        auto widget = static_cast<SieveGlobalVariableActionWidget *>(aWidget);
         widget->clear();
     }
     Q_EMIT valueChanged();
@@ -274,7 +280,7 @@ void SieveGlobalVariableLister::clearWidget(QWidget *aWidget)
 
 QWidget *SieveGlobalVariableLister::createWidget(QWidget *parent)
 {
-    auto *w = new SieveGlobalVariableActionWidget(parent);
+    auto w = new SieveGlobalVariableActionWidget(parent);
     reconnectWidget(w);
     return w;
 }
@@ -296,7 +302,11 @@ SieveGlobalVariableActionWidget::VariableElement SieveGlobalVariableLister::load
     QString variableValue;
     int index = 0;
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("str")) {
             if (index == 0) {
                 variableName = element.readElementText();
@@ -314,7 +324,7 @@ SieveGlobalVariableActionWidget::VariableElement SieveGlobalVariableLister::load
     const QList<QWidget *> lstWidget = widgets();
     bool globalVariableFound = false;
     for (QWidget *widget : lstWidget) {
-        auto *w = static_cast<SieveGlobalVariableActionWidget *>(widget);
+        auto w = static_cast<SieveGlobalVariableActionWidget *>(widget);
         if (w->variableName() == variableName) {
             w->setVariableValue(variableValue);
             globalVariableFound = true;
