@@ -16,12 +16,11 @@
 #include "sieveeditormenubar.h"
 #include "sieveeditortextmodewidget.h"
 
+#include "libksieve_debug.h"
 #include <KActionMenu>
 #include <KLocalizedString>
 #include <KStandardAction>
-#include <kzip.h>
 #include <PimCommon/PurposeMenuWidget>
-#include "libksieve_debug.h"
 #include <QAction>
 #include <QLabel>
 #include <QLineEdit>
@@ -30,6 +29,7 @@
 #include <QStandardPaths>
 #include <QToolBar>
 #include <QVBoxLayout>
+#include <kzip.h>
 
 using namespace KSieveUi;
 
@@ -92,7 +92,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
         connect(menuBar, &SieveEditorMenuBar::zoomOut, this, &SieveEditorWidget::zoomOut);
         connect(menuBar, &SieveEditorMenuBar::zoomReset, this, &SieveEditorWidget::zoomReset);
         connect(menuBar, &SieveEditorMenuBar::debugSieveScript, this, &SieveEditorWidget::debugSieveScript);
-        connect(menuBar, &SieveEditorMenuBar::wordWrap, this, &SieveEditorWidget::wordWrap);
+        connect(menuBar, &SieveEditorMenuBar::wordWrap, this, &SieveEditorWidget::setWordWrap);
         connect(menuBar, &SieveEditorMenuBar::print, this, &SieveEditorWidget::print);
         connect(menuBar, &SieveEditorMenuBar::printPreview, this, &SieveEditorWidget::printPreview);
 
@@ -264,10 +264,10 @@ void SieveEditorWidget::printPreview()
     }
 }
 
-void SieveEditorWidget::wordWrap(bool state)
+void SieveEditorWidget::setWordWrap(bool state)
 {
     if (mMode == TextMode) {
-        mTextModeWidget->wordWrap(state);
+        mTextModeWidget->setWordWrap(state);
     }
 }
 
