@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -28,16 +28,14 @@
 #include <KGuiItem>
 #include <KSharedConfig>
 #include <KStandardGuiItem>
-#include <errno.h>
+#include <cerrno>
 
 using namespace KSieveUi;
 
 class KSieveUi::ManageSieveScriptsDialogPrivate
 {
 public:
-    ManageSieveScriptsDialogPrivate()
-    {
-    }
+    ManageSieveScriptsDialogPrivate() = default;
 
     CustomManageSieveWidget *mTreeView = nullptr;
     SieveEditor *mSieveEditor = nullptr;
@@ -62,7 +60,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
 {
     setWindowTitle(i18nc("@title:window", "Manage Sieve Scripts"));
     setModal(false);
-    setAttribute(Qt::WA_GroupLeader);
+    setWindowModality(Qt::WindowModal);
     setAttribute(Qt::WA_DeleteOnClose);
     auto mainLayout = new QVBoxLayout(this);
     auto frame = new QFrame;
@@ -101,7 +99,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
     connect(close, &QPushButton::clicked, this, &ManageSieveScriptsDialog::accept);
     buttonLayout->addWidget(close);
 
-    KConfigGroup group(KSharedConfig::openConfig(), "ManageSieveScriptsDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "ManageSieveScriptsDialog");
     const QSize size = group.readEntry("Size", QSize());
     if (size.isValid()) {
         resize(size);
@@ -113,7 +111,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
 ManageSieveScriptsDialog::~ManageSieveScriptsDialog()
 {
     disconnect(d->mTreeView, &CustomManageSieveWidget::updateButtons, this, &ManageSieveScriptsDialog::slotUpdateButtons);
-    KConfigGroup group(KSharedConfig::openConfig(), "ManageSieveScriptsDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "ManageSieveScriptsDialog");
     group.writeEntry("Size", size());
     // prevent QTreeWidget signals triggered by it's destructor from calling our slots
     d->mTreeView->disconnect(this);
