@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,7 +20,7 @@
 #include <KPIMTextEdit/PlainTextEditorWidget>
 #include <Libkdepim/LineEditCatchReturnKey>
 
-#include <kmime/kmime_header_parsing.h>
+#include <KMime/HeaderParsing>
 
 #include <PimCommon/SpellCheckLineEdit>
 #include <QCheckBox>
@@ -153,7 +153,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     mIntervalSpin->setValue(defDayInterval);
     mIntervalSpin->setObjectName(QStringLiteral("mIntervalSpin"));
     mIntervalSpin->setSuffix(i18np(" day", " days", defDayInterval));
-    connect(mIntervalSpin, QOverload<int>::of(&QSpinBox::valueChanged), this, &VacationEditWidget::slotIntervalSpinChanged);
+    connect(mIntervalSpin, &QSpinBox::valueChanged, this, &VacationEditWidget::slotIntervalSpinChanged);
     auto resendNotificationLabel = new QLabel(i18n("&Resend notification only after:"), this);
     resendNotificationLabel->setObjectName(QStringLiteral("resendNotificationLabel"));
     resendNotificationLabel->setBuddy(mIntervalSpin);
@@ -178,7 +178,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
         mMailAction->addItem(VacationUtils::mailAction(static_cast<VacationUtils::MailAction>(i)));
     }
     mMailAction->setObjectName(QStringLiteral("mMailAction"));
-    connect(mMailAction, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &VacationEditWidget::mailActionChanged);
+    connect(mMailAction, &QComboBox::currentIndexChanged, this, &VacationEditWidget::mailActionChanged);
 
     // Add imap select folder plugin here.
     mMailActionRecipient = new VacationMailActionWidget(this);
@@ -225,9 +225,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     connect(mDomainEdit, &QLineEdit::textChanged, this, &VacationEditWidget::setWasChanged);
 }
 
-VacationEditWidget::~VacationEditWidget()
-{
-}
+VacationEditWidget::~VacationEditWidget() = default;
 
 bool VacationEditWidget::activateVacation() const
 {
@@ -288,10 +286,9 @@ AddrSpecList VacationEditWidget::mailAliases(bool &ok) const
 void VacationEditWidget::setMailAliases(const AddrSpecList &aliases)
 {
     QStringList sl;
-    AddrSpecList::const_iterator end(aliases.constEnd());
     sl.reserve(aliases.count());
-    for (AddrSpecList::const_iterator it = aliases.constBegin(); it != end; ++it) {
-        sl.push_back((*it).asString());
+    for (const auto &str : aliases) {
+        sl.push_back(str.asString());
     }
     mMailAliasesEdit->setText(sl.join(QLatin1String(", ")));
 }
@@ -410,7 +407,7 @@ QString VacationEditWidget::subject() const
     if (mSubject->isEnabled()) {
         return mSubject->toPlainText();
     } else {
-        return QString();
+        return {};
     }
 }
 
